#!/usr/bin/python

import sys
import argparse

from itertools import tee, izip

def main():
    parser = argparse.ArgumentParser(description="""
    
    python make_triangular.py

    Make sure that the coordinates passed in are triangular. Sorts the first two
    columns so that the resulting coordinates are triangular.

""")

    args = parser.parse_args()

    for line in sys.stdin:
        try:
            line_output = []
            line_parts = line.strip().split()

            if int(line_parts[0]) > int(line_parts[1]):
                out_parts = [line_parts[1], line_parts[0]] + line_parts[2:]
            else:
                out_parts = line_parts

            print "\t".join(out_parts)
            
        except KeyError as ke:
            print >>sys.stderr, "KeyError:", ke, line.strip()
    

if __name__ == '__main__':
    main()






#!/usr/bin/python
from __future__ import print_function

import negspy.coordinates as nc
import sys
import argparse

from itertools import tee

def pairwise(iterable):
    "s -> (s0, s1), (s2, s3), (s4, s5), ..."
    a = iter(iterable)
    return zip(a, a)

def main():
    parser = argparse.ArgumentParser(description="""
    
    python chr_pos_to_genome_pos.py 

    Convert chromosome,position pairs to genome_positions. Assumes that the
    coordinates refer to the hg19 assembly.

""")

    parser.add_argument('-a', '--assembly', default='hg19')


    parser.add_argument('-e', '--extra-columns', default='',
                         help="Some option", type=str)
    #parser.add_argument('-u', '--useless', action='store_true', 
    #                     help='Another useless option')
    args = parser.parse_args()

    for line in sys.stdin:
        try:
            line_output = []
            line_parts = line.strip().split()
            for chrom, pos in pairwise(line_parts):
                genome_pos = nc.chr_pos_to_genome_pos( chrom, int(pos), args.assembly)
                line_output += [genome_pos]
            for col in args.extra_columns.split(','):
                line_output += [line_parts[int(col)-1]]
            print("\t".join(map(str, line_output)))
        except KeyError as ke:
            print("KeyError:", ke, line.strip(), file=sys.stderr)
    

if __name__ == '__main__':
    main()





import csv
import os.path as op

class ChromosomeInfo:
    def __init__(self, name):
        self.name = name
        self.total_length = 0
        self.cum_chrom_lengths = {}

chromInfo = {}

for assembly in ['hg19', 'hg38', 'mm9']:
    chromInfo[assembly] = ChromosomeInfo(assembly)
    with open(op.join(op.dirname(__file__), 'data/{}/chromInfo.txt'.format(assembly)), 'r') as f:
        reader = csv.reader(f, delimiter='\t')
        totalLength = 0

        for rec in reader:
            totalLength += int(rec[1])

            chromInfo[assembly].cum_chrom_lengths[rec[0]] = totalLength - int(rec[1])

        chromInfo[assembly].total_length = totalLength

def chr_pos_to_genome_pos(chromosome, nucleotide, assembly='hg19'):
    '''
    Convert chromsome / nucleotide coordinates to genome coordinates.

    Example: chr1:10 -> 10
    Example: chr2:10 -> 247,249,729 

    Where the length of chromosome 1 is 247,249,719.

    :param chromosome: The name of a chromosome (i.e. chr1)
    :param nucleotide: The nucleotide number within the chromosome
    :param chromInfo: The lengths of all the chromosomes in the genome assembly
    :return: A single integer representing the position of the read if all the chromosomes were
             concatenated
    '''
    if assembly not in chromInfo.keys():
        raise KeyError('No chromosome lengths for assembly {}'.format(assembly))

    return chromInfo[assembly].cum_chrom_lengths[chromosome] + nucleotide




from distutils.core import setup

setup(name='negspy',
      version='0.1.1',
      description='Python NGS tools',
      author='Peter Kerpedjiev',
      author_email='pkerpedjiev@gmail.com',
      url='',
      packages=['negspy'],
      package_data={'negspy': ['data/*/chromInfo.txt']},
      scripts=['scripts/chr_pos_to_genome_pos.py', 'scripts/make_triangular.py'],

     )
